Mass

Enum Mass 

#[non_exhaustive]
pub enum Mass { ShortTon, LongTon, Pound, Ounce, Tonne, Kilogram, Gram, Centigram, Milligram, Microgram, AtomicMassUnit, }
A unit of mass.

The listed abbreviations are the abbreviations used to parse the unit with FromStr. The main abbreviation comes first, followed by any alternate abbreviations that can be used.

The conversions are listed in terms of the base unit. The base unit for Mass is Mass::Kilogram.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ShortTon

A US (short) ton (2000 pounds).

  • Abbreviation: tn

  • 1 tn = 907.18474 kg



LongTon

An imperial (long) ton (2240 pounds).

  • Abbreviation: lt

  • 1 lt = 1016.0469088 kg



Pound

  • Abbreviation: lb

  • 1 lb = 0.45359237 kg



Ounce

  • Abbreviation: oz

  • 1 oz = 0.028349523125 kg



Tonne

A metric tonne (1000 kilograms).

  • Abbreviation: t

  • 1 t = 1000.0 kg



Kilogram

  • Abbreviation: kg

  • 1 kg = 1.0 kg



Gram

  • Abbreviation: g

  • 1 g = 0.001 kg



Centigram

  • Abbreviation: cg

  • 1 cg = 1e-5 kg



Milligram

  • Abbreviation: mg

  • 1 mg = 1e-6 kg



Microgram

  • Abbreviation: µg, ug

  • 1 µg = 1e-9 kg



AtomicMassUnit

An atomic mass unit (1/12 of the mass of a carbon 12 atom).

  • Abbreviation: amu

  • 1 amu = 1.66053906892e-27 kg

Implementations

Source

impl Mass

pub fn pow(&self, power: i8) -> Unit

Creates a Unit with this quantity type and specified power.

pub fn squared(&self) -> Unit

Creates a Unit with this quantity type and power 2.

pub fn cubed(&self) -> Unit

Creates a Unit with this quantity type and power 3.