#[non_exhaustive]pub struct Unit { /* private fields */ }Expand description
A unit of measurement that includes a power.
Implementations
Sourceimpl Unit
impl Unit
Sourcepub fn new(quantity: impl Into<Base>) -> Self
pub fn new(quantity: impl Into<Base>) -> Self
Creates a new unit with the given quantity, with power 1.
Sourcepub fn with_power(quantity: impl Into<Base>, power: i8) -> Self
pub fn with_power(quantity: impl Into<Base>, power: i8) -> Self
Creates a new unit with the given quantity and power.
Sourcepub fn conversion_factor(&self, target: Unit) -> Result<f64, ConversionError>
pub fn conversion_factor(&self, target: Unit) -> Result<f64, ConversionError>
If this unit can be converted to the target unit, returns the conversion factor between them.